@@ -152,7 +152,7 @@ fn run_pattern_with_printer(arg: RunArg, printer: impl Printer + 'static) -> Res
   } else if arg.lang.is_some() {
     RunWithSpecificLang::new(arg, printer)?.run_path()
   } else {
-    let trace = arg.output.tracing.run_trace();
+    let trace = arg.output.inspect.run_trace();
     RunWithInferredLang {
       arg,
       printer,
@@ -189,10 +189,7 @@ impl<P: Printer> Worker for RunWithInferredLang<P> {
       }
     }
     printer.after_print()?;
-    // TODO: better handle output format
-    if let Some(trace) = self.trace.print(self.arg.output.json.is_some()) {
-      eprintln!("{}", trace);
-    }
+    self.trace.print()?;
     Ok(())
   }
 }
@@ -207,6 +204,7 @@ impl<P: Printer> PathWorker for RunWithInferredLang<P> {
 
   fn produce_item(&self, path: &Path) -> Option<Vec<Self::Item>> {
     let lang = SgLang::from_path(path)?;
+    self.trace.print_file(path, lang).ok()?;
     let matcher = self.arg.build_pattern(lang).ok()?;
     // match sub region
     if let Some(sub_langs) = lang.injectable_sg_langs() {
@@ -241,7 +239,7 @@ impl<Printer> RunWithSpecificLang<Printer> {
     } else {
       None
     };
-    let stats = arg.output.tracing.run_trace();
+    let stats = arg.output.inspect.run_trace();
     Ok(Self {
       arg,
       printer,
@@ -264,9 +262,7 @@ impl<P: Printer> Worker for RunWithSpecificLang<P> {
       has_matches = true;
     }
     printer.after_print()?;
-    if let Some(stats) = self.stats.print(self.arg.output.json.is_some()) {
-      eprintln!("{}", stats);
-    }
+    self.stats.print()?;
     if !has_matches && self.pattern.has_error() {
       Err(anyhow::anyhow!(EC::PatternHasError))
     } else {
@@ -288,6 +284,7 @@ impl<P: Printer> PathWorker for RunWithSpecificLang<P> {
     let pattern = self.pattern.clone();
     let lang = arg.lang.expect("must present");
     let path_lang = SgLang::from_path(path)?;
+    self.stats.print_file(path, path_lang).ok()?;
     let ret = if path_lang == lang {
       filter_file_pattern(path, lang, Some(pattern), std::iter::empty())?
     } else {
@@ -358,7 +355,7 @@ mod test {
         interactive: false,
         json: None,
         update_all: false,
-        tracing: Default::default(),
+        inspect: Default::default(),
       },
       context: ContextArgs {
         before: 0,
